@@ -2,8 +2,6 @@ package AnyEvent::RabbitMQ;
 
 use strict;
 use warnings;
-
-use Data::Dumper;
 use Carp qw(confess croak);
 use List::MoreUtils qw(none);
 use Devel::GlobalDestruction;
@@ -11,6 +9,17 @@ use namespace::clean;
 use File::ShareDir;
 use Readonly;
 
+require Data::Dumper;
+sub Dumper {
+    local $Data::Dumper::Terse = 1;
+    local $Data::Dumper::Indent = 1;
+    local $Data::Dumper::Useqq = 1;
+    local $Data::Dumper::Deparse = 1;
+    local $Data::Dumper::Quotekeys = 0;
+    local $Data::Dumper::Sortkeys = 1;
+    &Data::Dumper::Dumper
+}
+
 use AnyEvent::Handle;
 use AnyEvent::Socket;
 
@@ -20,7 +29,7 @@ use Net::AMQP::Common qw(:all);
 use AnyEvent::RabbitMQ::Channel;
 use AnyEvent::RabbitMQ::LocalQueue;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 Readonly my $DEFAULT_AMQP_SPEC
     => File::ShareDir::dist_dir("AnyEvent-RabbitMQ") . '/fixed_amqp0-8.xml';
