@@ -3,7 +3,7 @@ package AnyEvent::RabbitMQ::LocalQueue;
 use strict;
 use warnings;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 sub new {
     my $class = shift;
@@ -45,5 +45,16 @@ sub _drain_queue {
     return $self;
 }
 
+sub _flush {
+    my ($self, $frame) = @_;
+
+    $self->_drain_queue;
+
+    while (my $cb = shift @{$self->{_drain_code_queue}}) {
+        local $@; # Flush frames immediately, throwing away errors for on-close
+        eval { $cb->($frame) };
+    }
+}
+
 1;
 
